@@ -7,7 +7,7 @@ from tempfile import NamedTemporaryFile
 from typing import Optional, Type, List, Dict, Tuple, Set, Any, Callable
 from mergedeep import merge, Strategy as mergeStrategy
 from collections import defaultdict
-from pydantic import BaseModel
+from pydantic import BaseModel, main
 from functools import cached_property
 from splight_lib.execution import ExecutionClient, Thread
 from splight_lib.logging import logging
@@ -76,7 +76,7 @@ class IndexMixin:
     def __get_collections(self) -> List[str]:
         native_output_types = [Boolean, String, Number]
         # TODO do this autodiscovery better
-        component_output_types = [v for v in self.output.__dict__.values() if isinstance(v, BaseModel)]
+        component_output_types = [v for v in self.output.__dict__.values() if isinstance(v, main.ModelMetaclass)]
         return [r.Meta.collection_name for r in native_output_types + component_output_types]
 
     def __get_indexes(self) -> List[Tuple[str, int]]:
@@ -304,6 +304,8 @@ class ParametersMixin:
         }
         for parameter in parameters:
             parameter = parameter.dict() if not isinstance(parameter, dict) else parameter
+            if parameter["value"] is None:
+                continue
             values = parameter["value"] if parameter["multiple"] else [parameter["value"]]
             if parameter["type"] in NATIVE_TYPES:
                 continue
@@ -339,7 +341,7 @@ class ParametersMixin:
             type = parameter["type"]
             value = parameter["value"]
             multiple = parameter["multiple"]
-            if type in NATIVE_TYPES:
+            if type in NATIVE_TYPES or value is None:
                 parameter["value"] = value
             elif type in DATABASE_TYPES or type in STORAGE_TYPES:
                 parameter["value"] = [objects[val] for val in value] if multiple else objects[value]
@@ -384,6 +386,7 @@ class AbstractComponent(RunnableMixin, HooksMixin, IndexMixin, BindingsMixin, Pa
         self.namespace = self._setup.settings.NAMESPACE
         self.instance_id = self._setup.settings.COMPONENT_ID
         self.instance_type = Component
+        self.deployment_id = run_spec.pop("id", None)
 
         self._spec: Deployment = Deployment(id=self.instance_id, **run_spec)
         self._load_instance_kwargs_for_clients()
